<?php

/**
 * @file
 * Drush integration file.
 *
 * Drush commands:
 *  - search-api-index-fast [index] [clear]
 *    Index with search api by using a lot of workers.
 *  - search-api-index-fast-queue [index] [worker]
 *    Worker process.
 */

/**
 * Class SearchApiFast.
 *
 * Used for defining some variables.
 */
class SearchApiFastSettings {

  /**
   * Each worker is actually a seperate drush process.
   *
   * @return int
   *   The number of workers.
   */
  public static function getIndexWorkers() {
    return variable_get('search_api_fast_index_workers', 8);
  }

  /**
   * Batches to be handled by each worker before it's respawned.
   *
   * If chaining this, you should take memory consumption into account.
   *
   * @return int
   *   The number of workers per batch.
   */
  public static function getWorkerRespawn() {
    return variable_get('search_api_fast_max_batches_worker_respawn', 4);
  }

  /**
   * Batch size (items to index).
   *
   * @return int
   *   The number of items to index.
   */
  public static function getBatchSize() {
    return variable_get('search_api_fast_worker_batch_size', 100);
  }
}

/**
 * Implements hook_drush_command().
 */
function search_api_fast_drush_command() {

  // Include callbacks.
  include_once 'includes/search_api_fast_index.inc';

  $items = [];

  // Init fast indexing.
  $items['search-api-index-fast'] = [
    'aliases' => ['sapi-fast'],
    'description' => 'Index everything with use of multiple workers',
    'bootstrap' => 'DRUSH_BOOTSTRAP_DRUPAL_FULL',
    'callback' => 'search_api_fast_index_fast',
    'arguments' => [
      'index' => 'index machine name to run on.',
      'clear' => 'provide "clear" to clear the index first or "reindex" to reindex',
    ],
    'examples' => [
      'drush search-api-index-fast [index] clear' => dt('Index [index], and clear it first (no reindex)'),
      'drush search-api-index-fast [index] reindex' => dt('Index [index], and mark for reindex first'),
      'drush search-api-index-fast [index]' => dt('Index without clearing, just whats left un-indexed.'),
    ],
  ];

  // Worker drush command.
  $items['search-api-index-fast-queue'] = [
    'aliases' => ['sapi-ifq'],
    'description' => 'Index everything with use of multiple workers: queue worker (dont manually use this)',
    'bootstrap' => 'DRUSH_BOOTSTRAP_DRUPAL_FULL',
    'callback' => 'search_api_fast_index_fast_queue_worker',
    'arguments' => [
      'index' => 'Index machine name',
      'worker' => 'The worker id, 0 to ' . SearchApiFastSettings::getIndexWorkers(),
    ],
  ];

  return $items;
}
